@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2011 Michael Zeising
+## Copyright (C) 2005-2013 Michael Zeising
 ##
 ## This file is part of Octave.
 ##
@@ -23,7 +23,8 @@
 ## Write @var{y} to the canonical RIFF/WAVE sound file @var{filename}
 ## with sample rate @var{Fs} and bits per sample @var{bps}.  The
 ## default sample rate is 8000 Hz with 16-bits per sample.  Each column
-## of the data represents a separate channel.
+## of the data represents a separate channel.  If @var{y} is either a
+## row vector or a column vector, it is written as a single channel.
 ## @seealso{wavread}
 ## @end deftypefn
 
@@ -50,11 +51,20 @@ function wavwrite (y, varargin)
     endif
   endif
 
+  ## calculate filesize
+  [n, channels] = size (y);
+
+  ## allow y to be a row vector
+  if (n == 1)
+    n = channels;
+    channels = 1;
+  endif
+
   ## test arguments
-  if (columns (y) < 1)
+  if (channels < 1)
     error ("wavwrite: Y must have at least one column");
   endif
-  if (columns (y) > 0x7FFF)
+  if (channels > 0x7FFF)
     error ("wavwrite: Y has more than 32767 columns (too many for a WAV-file)");
   endif
 
@@ -70,9 +80,6 @@ function wavwrite (y, varargin)
       error ("wavwrite: sample resolution not supported");
   endswitch
 
-  ## calculate filesize
-  [n, channels] = size (y);
-
   ## size of data chunk
   ck_size = n*channels*(bits_per_sample/8);
 
@@ -143,38 +150,69 @@ function wavwrite (y, varargin)
 endfunction
 
 
+%!shared fname
+%! fname = tmpnam ();
+
 %!test
-%! A = [-1:0.1:1; -1:0.1:1];
-%! wavwrite (A, "a.wav");
-%! [B, samples_per_sec, bits_per_sample] = wavread ("a.wav");
-%! assert(A,B, 1/2^15);
-%! assert(samples_per_sec, 8000);
-%! assert(bits_per_sample, 16);
-%! delete ("a.wav");
-%
+%! A = [-1:0.1:1; -1:0.1:1]';
+%! wavwrite (A, fname);
+%! [B, samples_per_sec, bits_per_sample] = wavread (fname);
+%! unlink (fname);
+%! assert (A,B, 1/2^15);
+%! assert (samples_per_sec, 8000);
+%! assert (bits_per_sample, 16);
+
 %!test
-%! A = [-1:0.1:1; -1:0.1:1];
-%! wavwrite (A, 4000, "a.wav");
-%! [B, samples_per_sec, bits_per_sample] = wavread ("a.wav");
-%! assert(A,B, 1/2^15);
-%! assert(samples_per_sec, 4000);
-%! assert(bits_per_sample, 16);
-%! delete ("a.wav");
-%
+%! A = [-1:0.1:1; -1:0.1:1]';
+%! wavwrite (A, 4000, fname);
+%! [B, samples_per_sec, bits_per_sample] = wavread (fname);
+%! unlink (fname);
+%! assert (A,B, 1/2^15);
+%! assert (samples_per_sec, 4000);
+%! assert (bits_per_sample, 16);
+
 %!test
-%! A = [-1:0.1:1; -1:0.1:1];
-%! wavwrite (A, 4000, 8, "a.wav");
-%! [B, samples_per_sec, bits_per_sample] = wavread ("a.wav");
-%! assert(A,B, 1/128);
-%! assert(samples_per_sec, 4000);
-%! assert(bits_per_sample, 8);
-%! delete ("a.wav");
-%
+%! A = [-1:0.1:1; -1:0.1:1]';
+%! wavwrite (A, 4000, 8, fname);
+%! [B, samples_per_sec, bits_per_sample] = wavread (fname);
+%! unlink (fname);
+%! assert (A,B, 1/128);
+%! assert (samples_per_sec, 4000);
+%! assert (bits_per_sample, 8);
+
 %!test
-%! A = [-2:2];
-%! wavwrite (A, "a.wav");
-%! B = wavread ("a.wav");
+%! A = [-2:2]';
+%! wavwrite (A, fname);
+%! B = wavread (fname);
+%! unlink (fname);
 %! B *= 32768;
-%! assert(B, [-32768 -32768 0 32767 32767]);
-%! delete ("a.wav");
+%! assert (B, [-32768 -32768 0 32767 32767]');
+
+%!test
+%! A = [-1:0.1:1];
+%! wavwrite (A, fname);
+%! [B, samples_per_sec, bits_per_sample] = wavread (fname);
+%! unlink (fname);
+%! assert (A', B, 1/2^15);
+%! assert (samples_per_sec, 8000);
+%! assert (bits_per_sample, 16);
+
+%!test
+%! A = [-1:0.1:1; -1:0.1:1]';
+%! wavwrite (A, fname);
+%! B = wavread (fname, 15);
+%! unlink (fname);
+%! assert (A(1:15,:) ,B, 1/2^15);
+%! wavwrite (A, fname);
+%! B = wavread (fname, [10, 20]);
+%! unlink (fname);
+%! assert (A(10:20,:) ,B, 1/2^15);
+
+%!test
+%! A = [-1:0.1:1; -1:0.1:1]';
+%! wavwrite (A, fname);
+%! [nsamp, nchan] = wavread (fname, "size");
+%! unlink (fname);
+%! assert (nsamp, 21);
+%! assert (nchan, 2);
 
