@@ -82,8 +82,12 @@ function t = __isequal__ (nans_compare_equal, x, varargin)
   ## From here on, compare objects as if they were structures.
   if (isobject (x))
     x = builtin ("struct", x);
-    varargin = cellfun (@(x) builtin ("struct", x), varargin,
-                        "uniformoutput", false);
+    for i = 1:numel (varargin)
+      if (! isobject (varargin{i}))
+        break;
+      endif
+      varargin{i} = builtin ("struct", varargin{i});
+    endfor
   endif
 
   if (t)
