@@ -1,5 +1,4 @@
-## Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2004,
-##               2005, 2006, 2007 John W. Eaton
+## Copyright (C) 1994-2013 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -27,7 +26,7 @@
 ## If @var{y} and @var{a} are polynomial coefficient vectors, @var{b} will
 ## contain the coefficients of the polynomial quotient and @var{r} will be
 ## a remainder polynomial of lowest order.
-## @seealso{conv, poly, roots, residue, polyval, polyderiv, polyinteg}
+## @seealso{conv, residue}
 ## @end deftypefn
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
@@ -41,7 +40,7 @@ function [b, r] = deconv (y, a)
   endif
 
   if (! (isvector (y) && isvector (a)))
-    error("conv: both arguments must be vectors");
+    error ("deconv: both arguments must be vectors");
   endif
 
   la = length (a);
@@ -55,7 +54,9 @@ function [b, r] = deconv (y, a)
   endif
 
   if (ly > la)
-    b = filter (y, a, [1, (zeros (1, ly - la))]);
+    x = zeros (size (y) - size (a) + 1);
+    x (1) = 1;
+    b = filter (y, a, x);
   elseif (ly == la)
     b = filter (y, a, 1);
   else
@@ -67,7 +68,7 @@ function [b, r] = deconv (y, a)
     r = y - conv (a, b);
   else
     ## Respect the orientation of Y"
-    if (size (y, 1) <= size (y, 2))
+    if (rows (y) <= columns (y))
       r = [(zeros (1, lc - ly)), y] - conv (a, b);
     else
       r = [(zeros (lc - ly, 1)); y] - conv (a, b);
@@ -79,3 +80,35 @@ function [b, r] = deconv (y, a)
   endif
 
 endfunction
+
+
+%!test
+%! [b, r] = deconv ([3, 6, 9, 9], [1, 2, 3]);
+%! assert (b, [3, 0]);
+%! assert (r, [0, 0, 0, 9]);
+
+%!test
+%! [b, r] = deconv ([3, 6], [1, 2, 3]);
+%! assert (b, 0);
+%! assert (r, [3, 6]);
+
+%!test
+%! [b, r] = deconv ([3, 6], [1; 2; 3]);
+%! assert (b, 0);
+%! assert (r, [3, 6]);
+
+%!test
+%! [b,r] = deconv ([3; 6], [1; 2; 3]);
+%! assert (b, 0);
+%! assert (r, [3; 6]);
+
+%!test
+%! [b, r] = deconv ([3; 6], [1, 2, 3]);
+%! assert (b, 0);
+%! assert (r, [3; 6]);
+
+%!assert (deconv ((1:3)',[1, 1]), [1; 1])
+
+%!error [b, r] = deconv ([3, 6], [1, 2; 3, 4])
+%!error [b, r] = deconv ([3, 6; 1, 2], [1, 2, 3])
+
