@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2011 Ivana Varekova & Radek Salac
+## Copyright (C) 2008-2013 Ivana Varekova & Radek Salac
 ##
 ## This file is part of Octave.
 ##
@@ -25,7 +25,7 @@
 ## permutation.
 ## The complexity of the algorithm is O(n) in
 ## terms of time and memory requirements.
-## @seealso{etreeplot, gplot,treeplot}
+## @seealso{etreeplot, gplot, treeplot}
 ## @end deftypefn
 
 function [x_coordinate, y_coordinate, height, s] = treelayout (tree, permutation)
@@ -141,10 +141,10 @@ function [x_coordinate, y_coordinate, height, s] = treelayout (tree, permutation
 
       ## We are in top level separator when we have one child and the
       ## flag is 1
-      if (columns(idx) == 1 && top_level == 1)
+      if (columns (idx) == 1 && top_level == 1)
         s++;
       else
-        # We aren't in top level separator now.
+        ## We aren't in top level separator now.
         top_level = 0;
       endif
       ## If there is not any descendant of "parent node":
@@ -152,7 +152,7 @@ function [x_coordinate, y_coordinate, height, s] = treelayout (tree, permutation
        left_most++;
        x_coordinate_r(par_number) = left_most;
        max_ht = min (max_ht, level);
-       if (length(stk) > 1 && find ((shift(stk,1)-stk) == 0) > 1
+       if (length (stk) > 1 && find ((shift (stk,1) - stk) == 0) > 1
            && stk(end,2) != stk(end-1,2))
           ## Return to the nearest branching the position to return
           ## position is the position on the stack, where should be
@@ -202,10 +202,28 @@ function [x_coordinate, y_coordinate, height, s] = treelayout (tree, permutation
   endif
 endfunction
 
-%!demo
-%! % Compute a simple tree layout
-%! [x,y,h,s]=treelayout([0 1 2 2])
 
-%!demo
+%!test
+%! % Compute a simple tree layout
+%! [x, y, h, s] = treelayout ([0, 1, 2, 2]);
+%! assert (x, [1.5, 1.5, 2, 1]);
+%! assert (y, [3, 2, 1, 1]);
+%! assert (h, 2);
+%! assert (s, 2);
+
+%!test
 %! % Compute a simple tree layout with defined postorder permutation
-%! [x,y,h,s]=treelayout([0 1 2 2],[1 2 3 4])
+%! [x, y, h, s] = treelayout ([0, 1, 2, 2], [1, 2, 4, 3]);
+%! assert (x, [1.5, 1.5, 1, 2]);
+%! assert (y, [3, 2, 1, 1]);
+%! assert (h, 2);
+%! assert (s, 2);
+
+%!test
+%! % Compute a simple tree layout with defined postorder permutation
+%! [x, y, h, s] = treelayout ([0, 1, 2, 2], [4, 2, 3, 1]);
+%! assert (x, [0, 0, 0, 1]);
+%! assert (y, [0, 0, 0, 3]);
+%! assert (h, 0);
+%! assert (s, 1);
+
